# xychart

## Objects

 * <span class="badge object-type-class"></span> [FieldConfig](./object-FieldConfig.md)
 * <span class="badge object-type-class"></span> [Options](./object-Options.md)
 * <span class="badge object-type-class"></span> [ScatterSeriesConfig](./object-ScatterSeriesConfig.md)
 * <span class="badge object-type-enum"></span> [ScatterShow](./object-ScatterShow.md)
 * <span class="badge object-type-enum"></span> [SeriesMapping](./object-SeriesMapping.md)
 * <span class="badge object-type-class"></span> [XYDimensionConfig](./object-XYDimensionConfig.md)
## Builders

 * <span class="badge builder"></span> [Panel](./builder-Panel.md)
 * <span class="badge builder"></span> [ScatterSeriesConfig](./builder-ScatterSeriesConfig.md)
 * <span class="badge builder"></span> [XYDimensionConfig](./builder-XYDimensionConfig.md)
